<?php
namespace Ep\Gath\Moto;

use Ep\Gath\Gath;
use Ep\Wp\View\AbstractView;
use Zend\Form\FormInterface;
use Zend\ServiceManager\AbstractPluginManager;

/**
 * Class SelectMotorcycle
 *
 * @package Gath\Moto\View
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/gath-moto
 */
class SelectMotorcycleView extends AbstractView
{
    /** @var Gath */
    private $gath;
    /** @var AbstractPluginManager */
    private $forms;
    /** @var SelectedMotorcycle */
    private $selected;

    public function __construct(
        Gath $gath,
        AbstractPluginManager $forms,
        SelectedMotorcycle $selected
    ) {
        $this->gath = $gath;
        $this->forms = $forms;
        $this->selected = $selected;
    }

    public function init(): void
    {
        parent::init();

        if (defined('DOING_AJAX')) {
            add_action('wp_ajax_gath_moto_get_models', [$this, 'ajax_getModels']);
            add_action('wp_ajax_nopriv_gath_moto_get_models', [$this, 'ajax_getModels']);

            add_action('wp_ajax_gath_moto_get_motorcycles', [$this, 'ajax_getMotorcycles']);
            add_action('wp_ajax_nopriv_gath_moto_get_motorcycles', [$this, 'ajax_getMotorcycles']);
        }
    }

    /**
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function ajax_getModels()
    {
        $brandId = intval($_POST['brand_id']);

        $models = $this->gath->getMotorcycleModels($brandId);
        $response = [];

        foreach ($models['Results'] as $model) {
            $response[$model['ModelId']] = $model['ModelName'];
        }

        asort($response);
        wp_send_json($response);
    }

    /**
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function ajax_getMotorcycles()
    {
        $modelId = intval($_POST['model_id']);

        $motorcycles = $this->gath->getMotorcyclesByModel($modelId);
        $response = [];

        foreach ($motorcycles['Results'] as $motorcycle) {
            $response[$motorcycle['MotoId']] = $motorcycle['Year'];
        }

        wp_send_json($response);
    }

    /**
     * Renderira view.
     *
     * @param array $args
     *
     * @return string
     */
    public function render(array $args = []): string
    {
        wp_enqueue_style('gath-moto');
        wp_enqueue_script('gath-moto');

        $form = $this->forms->get('gath.select_motorcycle');
        $form->setAttribute('action', get_permalink(get_option('woocommerce_shop_page_id')));

        if ($motorcycle = $this->selected->get()) {
            $form->setData([
                'brandId' => $motorcycle['BrandId'],
                'modelId' => $motorcycle['ModelId'],
                'motorcycleId' => $motorcycle['MotoId'],
            ]);
        }

        $image = isset($args['image_id']) && is_numeric($args['image_id']) && $args['image_id'] > 0
            ? wp_get_attachment_image_url($args['image_id'], 'full')
            : false;

        return $this->renderer->render('@gath/moto/select-motorcycle.html.twig', [
            'form' => $form,
            'image_url' => $image,
            'title' => $args['title'] ?? false,
        ]);
    }
}