<?php
namespace EpTest\Gath\Plugin;

use Ep\Gath\Gath;
use Ep\Gath\Plugin\Products;
use EpTest\Gath\IntegrationTestTrait;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;
use Solarium\Client;
use WP_Object_Cache;
use wpdb;
use Zend\Log\LoggerInterface;

/**
 * Class ProductsTest
 *
 * @package EpTest\Gath\Plugin
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/gath
 */
class ProductsTest extends TestCase
{
    use IntegrationTestTrait;

    public static function setUpBeforeClass()
    {
        parent::setUpBeforeClass();

        require_once __DIR__ . '/../../wordpress/wp-includes/cache.php';
        require_once __DIR__ . '/../../wordpress/wp-includes/formatting.php';
        require_once __DIR__ . '/../../wordpress/wp-includes/load.php';
        require_once __DIR__ . '/../../wordpress/wp-includes/option.php';
        require_once __DIR__ . '/../../wordpress/wp-includes/post.php';
        require_once __DIR__ . '/../../wordpress/wp-includes/plugin.php';
    }

    protected function setUp()
    {
        parent::setUp();

        global $wp_object_cache;

        $wp_object_cache = $this->createMock(WP_Object_Cache::class);
        $wp_object_cache
            ->method('get')
            ->willReturn(false);

        global $wpdb;

        $wpdb = $this->createMock(wpdb::class);
        $wpdb
            ->method('get_results')
            ->willReturn([]);
    }

    public function testWillCleanTheProductDescription()
    {
        /** @var MockObject|LoggerInterface $logger */
        $logger = $this->createMock(LoggerInterface::class);
        /** @var MockObject|Gath $gath */
        $gath = $this->createMock(Gath::class);
        $gath
            ->method('getProductsByCategory')
            ->willReturn([
                'ResultCount' => 1,
                'Results' => [[
                    'id' => 1,
                    'description' => '<span class="some-class" style="font-size: 12pt">Content</span>',
                ]],
            ]);

        /** @var MockObject|Client $search */
        $search = $this->createMock(Client::class);

        $plugin = new Products($gath, $logger, $search);
        $products = $plugin->getProductsByCategory(1);

        $this->assertEquals('<span>Content</span>', $products[0]->post_content);
    }
}